Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(833)

Unified Diff: content/browser/payments/payment_app_manager.h

Issue 2565423002: Revert of PaymentApp: Introduce PaymentAppDatabase class. (Closed)
Patch Set: Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/payments/payment_app_database.cc ('k') | content/browser/payments/payment_app_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/payments/payment_app_manager.h
diff --git a/content/browser/payments/payment_app_manager.h b/content/browser/payments/payment_app_manager.h
index 12287ab4a1f8459edeeb343765562f7a27fa5ec3..28d2e855a0d32b4f53c709fc40242bd0f0e33125 100644
--- a/content/browser/payments/payment_app_manager.h
+++ b/content/browser/payments/payment_app_manager.h
@@ -11,17 +11,19 @@
#include "base/memory/weak_ptr.h"
#include "components/payments/payment_app.mojom.h"
#include "content/common/content_export.h"
+#include "content/common/service_worker/service_worker_status_code.h"
#include "mojo/public/cpp/bindings/binding.h"
namespace content {
-class PaymentAppContextImpl;
+class PaymentAppContext;
+class ServiceWorkerRegistration;
class CONTENT_EXPORT PaymentAppManager
: public NON_EXPORTED_BASE(payments::mojom::PaymentAppManager) {
public:
PaymentAppManager(
- PaymentAppContextImpl* payment_app_context,
+ PaymentAppContext* payment_app_context,
mojo::InterfaceRequest<payments::mojom::PaymentAppManager> request);
~PaymentAppManager() override;
@@ -36,11 +38,29 @@
void GetManifest(const std::string& scope,
const GetManifestCallback& callback) override;
+ // SetManifest callbacks
+ void DidFindRegistrationToSetManifest(
+ payments::mojom::PaymentAppManifestPtr manifest,
+ const SetManifestCallback& callback,
+ ServiceWorkerStatusCode status,
+ scoped_refptr<ServiceWorkerRegistration> registration);
+ void DidSetManifest(const SetManifestCallback& callback,
+ ServiceWorkerStatusCode status);
+
+ // GetManifest callbacks
+ void DidFindRegistrationToGetManifest(
+ const GetManifestCallback& callback,
+ ServiceWorkerStatusCode status,
+ scoped_refptr<ServiceWorkerRegistration> registration);
+ void DidGetManifest(const GetManifestCallback& callback,
+ const std::vector<std::string>& data,
+ ServiceWorkerStatusCode status);
+
// Called when an error is detected on binding_.
void OnConnectionError();
- // PaymentAppContextImpl owns PaymentAppManager
- PaymentAppContextImpl* payment_app_context_;
+ // PaymentAppContext owns PaymentAppManager
+ PaymentAppContext* payment_app_context_;
mojo::Binding<payments::mojom::PaymentAppManager> binding_;
« no previous file with comments | « content/browser/payments/payment_app_database.cc ('k') | content/browser/payments/payment_app_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698